@@ -18,5 +18,7 @@ fa=group25.fa
     lamassemble -z10 -d100 $mat $fa
     lamassemble --end -z20 $mat $fa
     lamassemble -s2 -z20 $mat $fa
-} 2>&1 |
-    diff -u lama-tests.out -
+    lamassemble -c $mat group25-aln.fa
+    lamassemble -c -fFASTQ $mat group25-aln.fa
+    lamassemble PromethION-2019 $fa
+} 2>&1 | diff -u lama-tests.out -
